# ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from openapi_client.models.external_api_origin_update_waybill_created_emails_language import ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage

# TODO update the JSON string below
json = "{}"
# create an instance of ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage from a JSON string
external_api_origin_update_waybill_created_emails_language_instance = ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage.from_json(json)
# print the JSON string representation of the object
print(ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage.to_json())

# convert the object into a dict
external_api_origin_update_waybill_created_emails_language_dict = external_api_origin_update_waybill_created_emails_language_instance.to_dict()
# create an instance of ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage from a dict
external_api_origin_update_waybill_created_emails_language_from_dict = ExternalAPIOriginUpdateWaybillCreatedEmailsLanguage.from_dict(external_api_origin_update_waybill_created_emails_language_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


